@@ -157,8 +157,10 @@ sub _vmem_usage {
 		$stats->{peak_virtual_memory};
 	my $dreq     = _num_to_res($req);
 	my $dused    = _num_to_res($used);
-	if ($stats->{granted_pe} !~ /^(NONE|unknown)/ && $stats->{slots} =~ /^\d+/) {
-		$used /= $stats->{slots};
+	$run->_cpu_multiplier( $stats->{slots} )
+		if $stats->{granted_pe} !~ /^(NONE|unknown)/ && $stats->{slots} =~ /^\d+/;
+	if ($run->_cpu_multiplier > 1) {
+		$used /= $run->_cpu_multiplier;
 		$dused = _num_to_res($used) . ' per pe';
 	}
 	my $pct      = ( $used / $req ) * 100;
